"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StreamingConnection = void 0;
var StreamingConnection = /** @class */ (function () {
    function StreamingConnection(url, onMessage, logger) {
        this.url = url;
        this.onMessage = onMessage;
        this.logger = logger;
        this.openConnection();
    }
    StreamingConnection.prototype.openConnection = function () {
        var _this = this;
        if (typeof EventSource === 'undefined') {
            this.logger.warn('StreamingConnection not opened. EventSource is not available.');
            return;
        }
        this.connection = new EventSource(this.url, { withCredentials: true });
        this.connection.onmessage = function (event) {
            _this.onMessage(event.data);
        };
        this.connection.onerror = function () {
            _this.logger.warn('StreamingConnection warning. Connection failed to establish.');
        };
        this.connection.onopen = function () {
            _this.logger.debug('StreamingConnection opened');
        };
    };
    StreamingConnection.prototype.isConnected = function () {
        var _a, _b;
        return ((_a = this.connection) === null || _a === void 0 ? void 0 : _a.readyState) === ((_b = this.connection) === null || _b === void 0 ? void 0 : _b.OPEN);
    };
    StreamingConnection.prototype.reopen = function () {
        if (!this.isConnected()) {
            this.close();
            this.openConnection();
        }
    };
    StreamingConnection.prototype.close = function () {
        var _a;
        (_a = this.connection) === null || _a === void 0 ? void 0 : _a.close();
    };
    return StreamingConnection;
}());
exports.StreamingConnection = StreamingConnection;
//# sourceMappingURL=StreamingConnection.js.map